@@ -67,17 +67,6 @@ sub dump {
     my $workdir = "$basedir/dump/$self->{month}/$self->{date}";
     make_path($workdir) unless -d $workdir;
 
-    my $enc = Encode::Guess->guess($text);
-    if (ref $enc) {
-      eval { $text = $enc->decode($text); };
-      if (!!$@) {
-        warn("[dump] 字符串解码失败：$@");
-      }
-    }
-    else {
-      warn("[dump] 无法猜测编码: $enc");
-    }
-
     my $filename = "$workdir/$self->{host}_dump.txt";
     open(my $fh, '>>encoding(UTF-8)', $filename) or croak "无法打开文件 $filename 进行写入: $!";
     print $fh "$text\n"                          or croak "写入文件 $filename 失败: $!";
@@ -95,7 +84,7 @@ sub write_file {
   make_path($workdir) unless -d $workdir;
 
   my $enc = Encode::Guess->guess($config);
-  if (ref($enc)) {
+  if (ref $enc) {
     eval { $config = $enc->decode($config); };
     if (!!$@) {
       $self->dump("[write_file] $name 字符串解码失败：$@");
@@ -104,6 +93,7 @@ sub write_file {
   else {
     $self->dump("[write_file] $name 无法猜测编码: $enc");
   }
+
   $self->dump("[write_file] 准备将数据写入本地文件: ($workdir/$name)");
 
   my $filename = "$workdir/$name";
