@@ -126,7 +126,7 @@ sub runCommands {
 sub getConfig {
   my $self = shift;
 
-  my $commands = ["screen-length disable temporary", "screen-width 512", "dis current-configuration", "save" ];
+  my $commands = ["screen-length disable temporary", "screen-width 512", "dis current-configuration", "save", ];
 
   my $config = $self->execCommands($commands);
 
@@ -158,7 +158,7 @@ sub ftpConfig {
   my $host    = $self->{host};
   my $command = "put vrpcfg.zip $self->{month}/$self->{date}/";
 
-  $command .= $hostname ? "$hostname\_$host.txt'" : "$host.txt";
+  $command .= $hostname ? "$hostname\_$host.txt" : "$host.txt";
 
   my $exp    = $self->{exp};
   my $result = $exp ? ($exp->match() || '') : '';
